/**
 * Shows a simple message dialog, with a 'close' button. It uses a pre-rendered
 * dialog element that's globally defined for the whole app.
 * @param msg The message to show.
 * @returns A promise that resolves when the alert is closed.
 */
export function showAlert(msg: string): Promise<void> {
  const dialog = document.getElementById('alert-dialog') as HTMLDialogElement
  const messageBox = document.getElementById('alert-dialog-message') as HTMLParagraphElement
  const closeButton = document.getElementById('alert-dialog-close-button') as HTMLButtonElement
  closeButton.addEventListener('click', () => dialog.close())
  messageBox.innerText = msg
  dialog.showModal()
  return new Promise((resolve) => {
    dialog.addEventListener('close', () => resolve())
  })
}
